@@ -9,7 +9,6 @@ To see available commands
 
 """
 
-import setuptools  # to avoid a warning due to distutils_patch.py
 import os
 import json
 
@@ -23,11 +22,17 @@ setup_tpl_path = rjoin(data_dir, "setup_tpl")
 pyproject_toml_tpl_path = rjoin(data_dir, "pyproject_toml_tpl.toml")
 gitignore_tpl_path = rjoin(data_dir, ".gitignore_tpl")
 gitattributes_tpl_path = rjoin(data_dir, ".gitattributes_tpl")
+editorconfig_tpl_path = rjoin(data_dir, ".editorconfig_tpl")
 github_ci_tpl_path = rjoin(data_dir, "github_ci_tpl.yml")
 gitlab_ci_tpl_path = rjoin(data_dir, "gitlab_ci_tpl.yml")
 github_ci_tpl_deploy_path = rjoin(data_dir, "github_ci_tpl_deploy.yml")
 github_ci_tpl_publish_path = rjoin(data_dir, "github_ci_tpl_publish.yml")
+# New CI workflow for 2025:
 github_ci_publish_2025_path = rjoin(data_dir, "github_ci_publish_2025.yml")
+bug_report_tpl_path = rjoin(data_dir, "bug_report_tpl.md")
+feature_request_tpl_path = rjoin(data_dir, "feature_request_tpl.md")
+pull_request_template_tpl_path = rjoin(data_dir, "pull_request_template_tpl.md")
+dependabot_tpl_path = rjoin(data_dir, "dependabot_tpl.yml")
 
 pkg_dir = os.path.dirname(root_dir)
 pkg_join = lambda *paths: os.path.join(pkg_dir, *paths)
