@@ -1,3 +1,10 @@
+"""
+Populate a package directory with useful packaging files.
+
+Provides the `populate_pkg_dir` function to add standard files like
+README.md, pyproject.toml, and .gitignore.
+"""
+
 import os
 import shutil
 import json
@@ -15,10 +22,16 @@ from wads import (
     gitignore_tpl_path,
     gitattributes_tpl_path,
     github_ci_tpl_deploy_path,
-    github_ci_tpl_publish_path,
-    github_ci_publish_2025_path,
+    # github_ci_tpl_publish_path,  # old publish path
     wads_configs,
     wads_configs_file,
+    # New stuff:
+    github_ci_publish_2025_path,
+    editorconfig_tpl_path,
+    bug_report_tpl_path,
+    feature_request_tpl_path,
+    pull_request_template_tpl_path,
+    dependabot_tpl_path,
 )
 from wads.util import mk_conditional_logger, git, ensure_no_slash_suffix
 from wads.pack import write_configs
@@ -33,6 +46,77 @@ from wads.licensing import (
 
 path_sep = os.path.sep
 
+
+# --------------------------------------------------------------------------------------
+# Tracking and summary helpers for populate
+# --------------------------------------------------------------------------------------
+
+
+class PopulateTracker:
+    """Track actions during populate for summary reporting."""
+
+    def __init__(self):
+        self.skipped = []  # Files that existed and weren't overwritten
+        self.needs_attention = []  # Files with issues or misalignments
+        self.added = []  # Files that were created
+        self.errors = []  # Files that raised errors
+
+    def skip(self, filename: str):
+        """Record a file that was skipped (already exists)."""
+        self.skipped.append(filename)
+
+    def attention(self, filename: str, reason: str = None):
+        """Record a file that needs attention with optional reason."""
+        if reason:
+            self.needs_attention.append((filename, reason))
+        else:
+            self.needs_attention.append(filename)
+
+    def add(self, filename: str):
+        """Record a file that was added."""
+        self.added.append(filename)
+
+    def error(self, filename: str, error: str):
+        """Record a file operation that failed."""
+        self.errors.append((filename, error))
+
+    def print_summary(self, verbose=True):
+        """Print emoji-based summary of what happened."""
+        print("\n" + "=" * 60)
+        print("POPULATE SUMMARY")
+        print("=" * 60)
+
+        if self.skipped:
+            print("\n✓ Skipped (already exists):")
+            for item in self.skipped:
+                print(f"  • {item}")
+
+        if self.needs_attention:
+            print("\n👀 Needs attention:")
+            for item in self.needs_attention:
+                if isinstance(item, tuple):
+                    filename, reason = item
+                    print(f"  • {filename}")
+                    if verbose:
+                        print(f"    └─ {reason}")
+                else:
+                    print(f"  • {item}")
+
+        if self.added:
+            print("\n✅ Added:")
+            for item in self.added:
+                print(f"  • {item}")
+
+        if self.errors:
+            print("\n❌ Errors:")
+            for filename, error in self.errors:
+                print(f"  • {filename}")
+                if verbose:
+                    print(f"    └─ {error}")
+
+        print("\n" + "=" * 60)
+
+
 populate_dflts = wads_configs.get(
     "populate_dflts",
     {
@@ -155,6 +239,7 @@ def populate_pkg_dir(
     pkg_dir,
     version: str = populate_dflts["version"],
     description: str = populate_dflts["description"],
+    *,
     root_url: str | None = populate_dflts["root_url"],
     author: str | None = populate_dflts["author"],
     license: str = populate_dflts["license"],
@@ -172,6 +257,8 @@ def populate_pkg_dir(
     skip_ci_def_gen=False,
     migrate: bool = False,
     create_gitattributes: bool = True,
+    create_setup_py: bool = False,
+    create_community_files: bool = False,
     version_control_system=None,
     ci_def_path=None,
     ci_tpl_path=None,
@@ -208,6 +295,8 @@ def populate_pkg_dir(
     :param skip_docsrc_gen: Skip the generation of documentation stuff
     :param create_docsrc: If True, create and populate a `docsrc/` directory (overrides skip_docsrc_gen).
     :param skip_ci_def_gen: Skip the generation of the CI stuff
+    :param create_setup_py: If True, create setup.py for backward compatibility (default: False, not needed with Hatchling).
+    :param create_community_files: If True, create community files (.editorconfig, issue/PR templates, dependabot.yml). Default: False.
     :param migrate: If True, migrate existing setup.cfg to pyproject.toml and old CI to new CI format.
         Will fail if old CI has unmappable content.
     :param create_gitattributes: If True (default), create a .gitattributes file with '*.ipynb linguist-documentation'.
@@ -245,6 +334,7 @@ def populate_pkg_dir(
         overwrite = set(overwrite)
 
     _clog = mk_conditional_logger(condition=verbose, func=print)
+    tracker = PopulateTracker()
     pkg_dir = os.path.abspath(os.path.expanduser(pkg_dir))
     assert os.path.isdir(pkg_dir), f"{pkg_dir} is not a directory"
     pkg_dir = ensure_no_slash_suffix(pkg_dir)
@@ -314,15 +404,71 @@ def populate_pkg_dir(
 
     if should_update(".gitignore"):
         shutil.copy(gitignore_tpl_path, pjoin(".gitignore"))
+        tracker.add(".gitignore")
+    else:
+        tracker.skip(".gitignore")
 
     if create_gitattributes and should_update(".gitattributes"):
         _clog("... making a .gitattributes")
         shutil.copy(gitattributes_tpl_path, pjoin(".gitattributes"))
+        tracker.add(".gitattributes")
+    elif create_gitattributes:
+        tracker.skip(".gitattributes")
+
+    # Create community files only if requested
+    if create_community_files:
+        # Create .editorconfig for consistent formatting
+        if should_update(".editorconfig"):
+            shutil.copy(editorconfig_tpl_path, pjoin(".editorconfig"))
+            tracker.add(".editorconfig")
+        else:
+            tracker.skip(".editorconfig")
+
+        # Create GitHub issue templates
+        github_issue_template_dir = pjoin(".github", "ISSUE_TEMPLATE")
+        os.makedirs(github_issue_template_dir, exist_ok=True)
+
+        if should_update(pjoin(github_issue_template_dir, "bug_report.md")):
+            shutil.copy(
+                bug_report_tpl_path, pjoin(github_issue_template_dir, "bug_report.md")
+            )
+            tracker.add(".github/ISSUE_TEMPLATE/bug_report.md")
+        else:
+            tracker.skip(".github/ISSUE_TEMPLATE/bug_report.md")
+
+        if should_update(pjoin(github_issue_template_dir, "feature_request.md")):
+            shutil.copy(
+                feature_request_tpl_path,
+                pjoin(github_issue_template_dir, "feature_request.md"),
+            )
+            tracker.add(".github/ISSUE_TEMPLATE/feature_request.md")
+        else:
+            tracker.skip(".github/ISSUE_TEMPLATE/feature_request.md")
+
+        # Create PR template
+        if should_update(pjoin(".github", "PULL_REQUEST_TEMPLATE.md")):
+            shutil.copy(
+                pull_request_template_tpl_path,
+                pjoin(".github", "PULL_REQUEST_TEMPLATE.md"),
+            )
+            tracker.add(".github/PULL_REQUEST_TEMPLATE.md")
+        else:
+            tracker.skip(".github/PULL_REQUEST_TEMPLATE.md")
+
+        # Create Dependabot config
+        if should_update(pjoin(".github", "dependabot.yml")):
+            shutil.copy(dependabot_tpl_path, pjoin(".github", "dependabot.yml"))
+            tracker.add(".github/dependabot.yml")
+        else:
+            tracker.skip(".github/dependabot.yml")
 
     if project_type == "app":
         if should_update("requirements.txt"):
             with open(pjoin("requirements.txt"), "w") as f:
                 pass
+            tracker.add("requirements.txt")
+        else:
+            tracker.skip("requirements.txt")
 
     else:  # project_type == 'lib' or None
         if should_update("pyproject.toml"):
@@ -342,19 +488,25 @@ def populate_pkg_dir(
                     # Write the migrated content
                     with open(pjoin("pyproject.toml"), "w") as f:
                         f.write(pyproject_content)
+                    tracker.add("pyproject.toml")
+                    _clog("✅ Migrated setup.cfg → pyproject.toml")
                 except Exception as e:
                     _clog(
                         f"... migration failed ({e}), falling back to template-based creation"
                     )
+                    tracker.error("pyproject.toml", f"Migration failed: {e}")
                     if "pkg-dir" in configs:
                         del configs["pkg-dir"]
                     write_pyproject_configs(pjoin(""), configs)
+                    tracker.add("pyproject.toml")
             else:
                 _clog("... making a 'pyproject.toml'")
                 if "pkg-dir" in configs:
                     del configs["pkg-dir"]
                 write_pyproject_configs(pjoin(""), configs)
+                tracker.add("pyproject.toml")
         else:
+            tracker.skip("pyproject.toml")
             # If pyproject.toml exists but URL is missing/empty, update it
             if configs.get("url"):
                 from wads.toml_util import update_project_url, read_pyproject_toml
@@ -368,9 +520,13 @@ def populate_pkg_dir(
                         f"... updating URL in existing pyproject.toml to {configs['url']}"
                     )
                     update_project_url(pjoin(""), configs["url"])
-        # Keep setup.py for backward compatibility, but minimal
-        if should_update("setup.py"):
+        # setup.py is no longer needed with Hatchling, but can be created for backward compatibility
+        if create_setup_py and should_update("setup.py"):
             shutil.copy(setup_tpl_path, pjoin("setup.py"))
+            tracker.add("setup.py")
+        elif not create_setup_py and os.path.isfile(pjoin("setup.py")):
+            # If setup.py exists but we're not creating it, just skip it
+            tracker.skip("setup.py")
 
     if should_update("LICENSE"):
         _license_body = license_body(configs["license"])
@@ -398,12 +554,18 @@ def populate_pkg_dir(
         )
 
         save_txt_to_pkg("LICENSE", _license_body)
+        tracker.add("LICENSE")
+    else:
+        tracker.skip("LICENSE")
 
     if should_update("README.md"):
         readme_text = gen_readme_text(name, configs.get("description"))
         if include_pip_install_instruction_in_readme:
             readme_text += f"\n\nTo install:\t```pip install {name}```\n"
         save_txt_to_pkg("README.md", readme_text)
+        tracker.add("README.md")
+    else:
+        tracker.skip("README.md")
 
     if project_type is None or project_type == "lib":
         # Respect both the new `create_docsrc` flag and the existing
@@ -414,7 +576,20 @@ def populate_pkg_dir(
             _clog("... skipping docsrc generation because skip_docsrc_gen=True")
         elif create_docsrc:
             # TODO: Figure out epythet and wads relationship -- right now, there's a reflexive dependency
-            from epythet.setup_docsrc import make_docsrc
+            try:
+                from epythet.setup_docsrc import make_docsrc
+            except ImportError:
+                raise ImportError(
+                    "Documentation operations require epythet. "
+                    "Install wads with documentation support: pip install wads[docs]"
+                )
+
+            warn(
+                "Documentation generation with epythet is deprecated. "
+                "Install wads with documentation support: pip install wads[docs]",
+                DeprecationWarning,
+                stacklevel=2,
+            )
 
             make_docsrc(pkg_dir, verbose=verbose)
         else:
@@ -448,7 +623,12 @@ def populate_pkg_dir(
                         with open(ci_def_path, "w") as f:
                             f.write(new_ci_content)
                         _clog(f"... successfully migrated CI to {ci_def_path}")
+                        tracker.add(ci_def_path.replace(pkg_dir + os.sep, ""))
                     except Exception as e:
+                        tracker.error(
+                            ci_def_path.replace(pkg_dir + os.sep, ""),
+                            f"Migration failed: {e}",
+                        )
                         raise RuntimeError(
                             f"Failed to migrate CI file {old_ci_path}: {e}\n"
                             f"The old CI may contain configurations that cannot be automatically migrated."
@@ -459,10 +639,210 @@ def populate_pkg_dir(
                     _add_ci_def(
                         ci_def_path, ci_tpl_path, root_url, name, _clog, user_email
                     )
+                    tracker.add(ci_def_path.replace(pkg_dir + os.sep, ""))
             else:
                 # Not migrating or not github, use template
                 user_email = kwargs.get("user_email", "thorwhalen1@gmail.com")
                 _add_ci_def(ci_def_path, ci_tpl_path, root_url, name, _clog, user_email)
+                tracker.add(ci_def_path.replace(pkg_dir + os.sep, ""))
+        else:
+            tracker.skip(ci_def_path.replace(pkg_dir + os.sep, ""))
+
+    # -------------------------------------------------------------------------
+    # Compare existing files against templates and add attention items
+    # -------------------------------------------------------------------------
+    from wads.config_comparison import (
+        compare_pyproject_toml,
+        compare_setup_cfg,
+        compare_ci_workflow,
+    )
+
+    # Check pyproject.toml alignment
+    pyproject_path = pjoin("pyproject.toml")
+    if os.path.isfile(pyproject_path) and "pyproject.toml" not in tracker.added:
+        _clog("\n👀 Checking pyproject.toml alignment with template...")
+        comparison = compare_pyproject_toml(pyproject_path, project_name=name)
+        if comparison.get("needs_attention"):
+            reasons = []
+            if comparison.get("missing_sections"):
+                reasons.append(
+                    f"Missing sections: {', '.join(comparison['missing_sections'][:3])}"
+                    + ("..." if len(comparison['missing_sections']) > 3 else "")
+                )
+            for rec in comparison.get("recommendations", []):
+                reasons.append(rec)
+
+            tracker.attention("pyproject.toml", " | ".join(reasons))
+            if verbose:
+                _clog("  Issues found:")
+                for rec in comparison.get("recommendations", []):
+                    _clog(f"    • {rec}")
+
+    # Check setup.cfg (warn about deprecation)
+    setup_cfg_path = pjoin("setup.cfg")
+    if os.path.isfile(setup_cfg_path):
+        _clog("\n👀 Found setup.cfg (deprecated)...")
+        comparison = compare_setup_cfg(setup_cfg_path)
+        if comparison.get("should_migrate"):
+            tracker.attention(
+                "setup.cfg", "Deprecated format. Run: populate . --migrate"
+            )
+            if verbose:
+                _clog("  Consider migrating to pyproject.toml")
+                _clog("  Run: populate . --migrate")
+
+    # Check MANIFEST.in (warn about migration needed)
+    manifest_path = pjoin("MANIFEST.in")
+    if os.path.isfile(manifest_path):
+        from wads.config_comparison import compare_manifest_in
+
+        _clog("\n👀 Found MANIFEST.in (needs Hatchling migration)...")
+        manifest_comparison = compare_manifest_in(manifest_path)
+        if manifest_comparison.get("needs_migration"):
+            # If migrate flag is set, automatically add to pyproject.toml
+            if migrate and manifest_comparison.get("hatchling_config"):
+                pyproject_path = pjoin("pyproject.toml")
+                if os.path.isfile(pyproject_path):
+                    try:
+                        # Read existing pyproject.toml
+                        from wads.toml_util import read_pyproject_toml
+                        import tomli_w
+
+                        existing_data = read_pyproject_toml(pjoin(""))
+
+                        # Parse the hatchling config suggestion
+                        hatchling_lines = manifest_comparison["hatchling_config"].split(
+                            '\n'
+                        )
+
+                        # Extract include/exclude lists from the suggestion
+                        include_items = []
+                        exclude_items = []
+                        current_section = None
+
+                        for line in hatchling_lines:
+                            line = line.strip()
+                            if 'include = [' in line:
+                                current_section = 'include'
+                            elif 'exclude = [' in line:
+                                current_section = 'exclude'
+                            elif line.startswith('"') and current_section:
+                                # Extract the item (remove quotes, backslashes, and trailing comma)
+                                item = (
+                                    line.strip('"')
+                                    .strip('\\')
+                                    .rstrip(',')
+                                    .strip()
+                                    .strip('"')
+                                )
+                                if current_section == 'include':
+                                    include_items.append(item)
+                                else:
+                                    exclude_items.append(item)
+                            elif line == ']':
+                                current_section = None
+
+                        # Check if migration already done - only update if items missing
+                        if 'tool' not in existing_data:
+                            existing_data['tool'] = {}
+                        if 'hatch' not in existing_data['tool']:
+                            existing_data['tool']['hatch'] = {}
+                        if 'build' not in existing_data['tool']['hatch']:
+                            existing_data['tool']['hatch']['build'] = {}
+                        if 'targets' not in existing_data['tool']['hatch']['build']:
+                            existing_data['tool']['hatch']['build']['targets'] = {}
+                        if (
+                            'wheel'
+                            not in existing_data['tool']['hatch']['build']['targets']
+                        ):
+                            existing_data['tool']['hatch']['build']['targets'][
+                                'wheel'
+                            ] = {}
+
+                        wheel_config = existing_data['tool']['hatch']['build'][
+                            'targets'
+                        ]['wheel']
+
+                        # Check if items already present - skip if migration already done
+                        existing_include = set(wheel_config.get('include', []))
+                        existing_exclude = set(wheel_config.get('exclude', []))
+                        new_include = set(include_items)
+                        new_exclude = set(exclude_items)
+
+                        needs_update = False
+                        if include_items and not new_include.issubset(existing_include):
+                            wheel_config['include'] = include_items
+                            needs_update = True
+                        if exclude_items and not new_exclude.issubset(existing_exclude):
+                            wheel_config['exclude'] = exclude_items
+                            needs_update = True
+
+                        # Only write if changes needed
+                        if needs_update:
+                            with open(pyproject_path, 'wb') as f:
+                                tomli_w.dump(existing_data, f)
+
+                            _clog(
+                                "✅ Migrated MANIFEST.in → pyproject.toml [tool.hatch.build.targets.wheel]"
+                            )
+                            tracker.add("pyproject.toml (updated with MANIFEST.in)")
+                        else:
+                            _clog("✓ MANIFEST.in already migrated to pyproject.toml")
+                            tracker.skip(
+                                "pyproject.toml (MANIFEST.in already migrated)"
+                            )
+                    except Exception as e:
+                        _clog(f"⚠️  Could not auto-migrate MANIFEST.in: {e}")
+                        tracker.attention(
+                            "MANIFEST.in",
+                            "Auto-migration failed - see suggestions below",
+                        )
+                else:
+                    tracker.attention(
+                        "MANIFEST.in",
+                        "Needs migration but pyproject.toml not found",
+                    )
+            else:
+                tracker.attention(
+                    "MANIFEST.in",
+                    "Needs migration to Hatchling [tool.hatch.build.targets.wheel]",
+                )
+
+            if verbose and not (
+                migrate and manifest_comparison.get("hatchling_config")
+            ):
+                _clog("  MANIFEST.in is not directly supported by Hatchling")
+                for rec in manifest_comparison.get("recommendations", [])[:2]:
+                    _clog(f"  • {rec}")
+                if manifest_comparison.get("hatchling_config"):
+                    _clog("\n  Suggested pyproject.toml configuration:")
+                    for line in manifest_comparison["hatchling_config"].split('\n'):
+                        _clog(f"    {line}")
+
+    # Check CI workflow alignment
+    ci_path = pjoin(".github/workflows/ci.yml")
+    if (
+        os.path.isfile(ci_path)
+        and ci_path.replace(pkg_dir + os.sep, "") not in tracker.added
+    ):
+        _clog("\n👀 Checking CI workflow alignment with template...")
+        ci_comparison = compare_ci_workflow(ci_path, project_name=name)
+        if ci_comparison.get("needs_attention"):
+            reasons = [rec for rec in ci_comparison.get("recommendations", [])]
+            tracker.attention(
+                ".github/workflows/ci.yml",
+                " | ".join(reasons[:2]) + ("..." if len(reasons) > 2 else ""),
+            )
+            if verbose:
+                _clog("  Issues found:")
+                for rec in ci_comparison.get("recommendations", []):
+                    _clog(f"    • {rec}")
+
+    # Print summary
+    if verbose:
+        tracker.print_summary(verbose=True)
+    else:
+        tracker.print_summary(verbose=False)
 
     return name
 
